@@ -1,9 +1,9 @@
 from . import core, entry_func
 
-__version__ = '0.5.1'
+__version__ = '0.5.5'
 
 DEFAULT_OPTION_NAME = 'compiledb'
-DEFAULT_DB_NAME = 'compile_commands.json'
+DEFAULT_DB_NAME = '#/compile_commands.json'
 
 
 def enable(env, config=None):
